=head1 NAME

Level - defined report level 

=cut

package Level;

use warnings;
use strict;

## define your report level
## our $foo = 4;

our $Error  = 3;
our $Warn   = 2;
our $FATAL  = 1;
our $Thread = 0;

1;
